@@ -123,7 +123,7 @@ do_excel_write_prep_expr (ExcelWriteState *ewb, GnmExpr const *expr)
 		if (i >= excel_func_desc_size) {
 			ef->efunc = NULL;
 			if (func->flags & GNM_FUNC_IS_WORKBOOK_LOCAL) {
-				ef->macro_name = g_strdup (func->name); 
+				ef->macro_name = g_strdup (func->name);
 				ef->idx = -1;
 			} else {
 				g_ptr_array_add (ewb->externnames, func);
@@ -212,8 +212,8 @@ typedef enum {
 
 typedef struct {
 	ExcelWriteState *ewb;
-	Sheet	 	*sheet;
-	int	  	 col, row;
+	Sheet		*sheet;
+	int		 col, row;
 	gboolean	 use_name_variant;
 	XLContextType	 context;
 
@@ -228,20 +228,20 @@ static void write_node (PolishData *pd, GnmExpr const *expr,
 #define CLASS_VAL	0x20
 #define CLASS_ARRAY	0x40
 static const guint8 xl_op_class[NUM_CTXTS][NUM_XL_TYPES][NUM_XL_TYPES+1] = {
-	{ /* CELL | Wants REF	Wants VAL	Wants ARR 	From Root */
-/* From REF */	 { CLASS_REF,	CLASS_VAL,	CLASS_ARRAY, 	CLASS_VAL },
-/* From VAL */	 { CLASS_VAL,	CLASS_VAL,	CLASS_VAL, 	CLASS_VAL },
-/* From ARRAY */ { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY, 	CLASS_VAL },
+	{ /* CELL | Wants REF	Wants VAL	Wants ARR	From Root */
+/* From REF */	 { CLASS_REF,	CLASS_VAL,	CLASS_ARRAY,	CLASS_VAL },
+/* From VAL */	 { CLASS_VAL,	CLASS_VAL,	CLASS_VAL,	CLASS_VAL },
+/* From ARRAY */ { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY,	CLASS_VAL },
 	},
-	{ /* ARR  | Wants REF	Wants VAL	Wants ARR 	From Root */
-/* From REF */	 { CLASS_REF,	CLASS_VAL,	CLASS_ARRAY, 	CLASS_VAL },
-/* From VAL */	 { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY, 	CLASS_VAL },
-/* From ARRAY */ { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY, 	CLASS_ARRAY },
+	{ /* ARR  | Wants REF	Wants VAL	Wants ARR	From Root */
+/* From REF */	 { CLASS_REF,	CLASS_VAL,	CLASS_ARRAY,	CLASS_VAL },
+/* From VAL */	 { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY,	CLASS_VAL },
+/* From ARRAY */ { CLASS_ARRAY,	CLASS_VAL,	CLASS_ARRAY,	CLASS_ARRAY },
 	},
-	{ /* NAME | Wants REF	Wants VAL	Wants ARR 	From Root */
-/* From REF */	 { CLASS_REF,	CLASS_ARRAY,	CLASS_ARRAY, 	CLASS_REF },
-/* From VAL */	 { CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY, 	CLASS_ARRAY },
-/* From ARRAY */ { CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY, 	CLASS_ARRAY },
+	{ /* NAME | Wants REF	Wants VAL	Wants ARR	From Root */
+/* From REF */	 { CLASS_REF,	CLASS_ARRAY,	CLASS_ARRAY,	CLASS_REF },
+/* From VAL */	 { CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY },
+/* From ARRAY */ { CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY,	CLASS_ARRAY },
 	}
 };
 
@@ -444,7 +444,7 @@ excel_formula_write_AREA (PolishData *pd, GnmCellRef const *a, GnmCellRef const
 			ms_biff_put_var_write (pd->ewb->bp, data, 8);
 		}
 		return;
-	} 
+	}
 
 	g_return_if_fail (a->sheet != NULL);
 
@@ -531,7 +531,7 @@ write_funcall (PolishData *pd, GnmExpr const *expr,
 
 	for (arg = 0; arg < expr->func.argc; arg++)
 		if (ef->efunc != NULL && arg >= ef->efunc->max_args) {
-			gnm_io_warning (pd->ewb->io_context, 
+			gnm_io_warning (pd->ewb->io_context,
 				_("Too many arguments for function '%s', MS Excel can only handle %d not %d"),
 				ef->efunc->name, ef->efunc->max_args, arg);
 			break;
@@ -545,7 +545,7 @@ write_funcall (PolishData *pd, GnmExpr const *expr,
 		}
 
 	if (ef->efunc != NULL) {
-		guint8 op_class = xl_get_op_class (pd, 
+		guint8 op_class = xl_get_op_class (pd,
 			xl_map_char_to_type (ef->efunc->type), target_type);
 
 #if FORMULA_DEBUG > 1
@@ -570,7 +570,7 @@ write_funcall (PolishData *pd, GnmExpr const *expr,
 		push_guint8  (pd, FORMULA_PTG_FUNC_VAR +
 			xl_get_op_class (pd,  XL_VAL, target_type));
 		push_guint8  (pd, (arg + 1)	| (prompt   ? 0x80 : 0));
-		push_guint16 (pd, 0xff  	| (cmdequiv ? 0x8000 : 0));
+		push_guint16 (pd, 0xff		| (cmdequiv ? 0x8000 : 0));
 	}
 }
 
@@ -629,6 +629,7 @@ excel_formula_write_NAME_v7 (PolishData *pd, GnmExpr const *expr,
 		int externsheet = (pd->sheet == expr->name.optional_scope)
 			? (int) (pd->ewb->esheets->len + 1)
 			: expr->name.optional_scope->index_in_wb;
+		guint32 id = ++(pd->ewb->unique_name_id);
 
 		GSF_LE_SET_GUINT8  (data +  0, FORMULA_PTG_NAME_X +
 			xl_get_op_class (pd, XL_REF, target_type));
@@ -636,7 +637,7 @@ excel_formula_write_NAME_v7 (PolishData *pd, GnmExpr const *expr,
 		GSF_LE_SET_GUINT16 (data + 11, name_idx);
 		GSF_LE_SET_GUINT16 (data +  9,   1); /* undocumented marked 'reserved' */
 		GSF_LE_SET_GUINT16 (data + 19, 0xf); /* undocumented marked 'reserved' */
-		GSF_LE_SET_GUINT32 (data + 21, (guint32)expr); /* undocumented marked 'reserved' */
+		GSF_LE_SET_GUINT32 (data + 21, id); /* undocumented marked 'reserved' */
 		ms_biff_put_var_write (pd->ewb->bp, data, 25);
 	}
 }
@@ -647,7 +648,7 @@ write_node (PolishData *pd, GnmExpr const *expr, int paren_level,
 {
 	static struct {
 		guint8 xl_op;
-		int prec;	              /* Precedences -- should match parser.y  */
+		int prec;		      /* Precedences -- should match parser.y  */
 		int assoc_left, assoc_right;  /* 0: no, 1: yes.  */
 	} const operations [] = {
 		{ FORMULA_PTG_EQUAL,	 1, 1, 0 },
@@ -857,7 +858,7 @@ write_arrays (PolishData *pd)
 {
 	GnmValue const *array;
 	GSList  *ptr;
-	int  	 x, y;
+	int	 x, y;
 	guint8   data[8];
 	WriteStringFlags string_flags;
 
