@@ -6,7 +6,7 @@
  *    Uwe Steinmann <uwe@steinmann.cx>
  **/
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include <string.h>
 #include "px.h"
@@ -80,7 +80,7 @@ paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
 
 	PX_set_targetencoding(pxdoc, "UTF-8");
 
-	wb = wb_view_workbook (wb_view);
+	wb = wb_view_get_workbook (wb_view);
 	name = workbook_sheet_get_free_name (wb, pxh->px_tablename, FALSE, TRUE);
 	sheet = sheet_new (wb, name);
 	g_free (name);
@@ -103,9 +103,9 @@ paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
 		 */
 		PX_get_data_alpha(pxdoc, str, strlen(str), &str2);
 		fprintf(stderr, "%s\n", str2);
-		cell_set_text (cell, str2);
+		gnm_cell_set_text (cell, str2);
 #else
-		cell_set_text (cell, str);
+		gnm_cell_set_text (cell, str);
 #endif
 		pxf++;
 	}
@@ -221,7 +221,7 @@ paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
 					}
 				}
 				if(val)
-					cell_set_value (cell, val);
+					gnm_cell_set_value (cell, val);
 				offset += pxf->px_flen;
 				pxf++;
 			}
@@ -230,23 +230,23 @@ paradox_file_open (GOFileOpener const *fo, IOContext *io_context,
 				cell = sheet_cell_fetch (sheet, i++, row);
 				if(0 < PX_get_data_short(pxdoc, &data[offset], 2, &value)) {
 					val = value_new_int (value);
-					cell_set_value (cell, val);
+					gnm_cell_set_value (cell, val);
 				}
 				offset += 2;
 				cell = sheet_cell_fetch (sheet, i++, row);
 				if(0 < PX_get_data_short(pxdoc, &data[offset], 2, &value)) {
 					val = value_new_int (value);
-					cell_set_value (cell, val);
+					gnm_cell_set_value (cell, val);
 				}
 				offset += 2;
 				cell = sheet_cell_fetch (sheet, i++, row);
 				if(0 < PX_get_data_short(pxdoc, &data[offset], 2, &value)) {
 					val = value_new_int (value);
-					cell_set_value (cell, val);
+					gnm_cell_set_value (cell, val);
 				}
 				cell = sheet_cell_fetch (sheet, i++, row);
 				val = value_new_int (pxdbinfo.number);
-				cell_set_value (cell, val);
+				gnm_cell_set_value (cell, val);
 			}
 		}
 		row++;
@@ -268,7 +268,7 @@ paradox_file_probe (GOFileOpener const *fo, GsfInput *input,
 
 	pxdoc = PX_new();
 	if (PX_open_gsf (pxdoc, input) < 0) {
-		return false;
+		return FALSE;
 	}
 
 	pxh = pxdoc->px_head;
@@ -276,6 +276,5 @@ paradox_file_probe (GOFileOpener const *fo, GsfInput *input,
 	PX_close (pxdoc);
 	PX_delete (pxdoc);
 
-	return true;
+	return TRUE;
 }
-
