@@ -25,7 +25,7 @@
 
 /* TODO: Limit the number of include files a bit */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "psiconv-plugin.h"
 #include "application.h"
@@ -424,15 +424,19 @@ parse_subexpr(const psiconv_formula psi_formula)
 	return NULL;
 }
 
-static GnmExpr const *
+static GnmExprTop const *
 expr_new_from_formula (const psiconv_sheet_cell psi_cell,
 		       const psiconv_formula_list psi_formulas)
 {
-	psiconv_formula formula;
+	psiconv_formula formula = psiconv_get_formula (psi_formulas, psi_cell->ref_formula);
 
-	formula = psiconv_get_formula (psi_formulas, psi_cell->ref_formula);
+	if (NULL != formula) {
+		GnmExpr const *expr = parse_subexpr (formula);
+		if (NULL != expr)
+			return gnm_expr_top_new	(expr);
+	}
 
-	return (formula != NULL) ?  parse_subexpr (formula) : NULL;
+	return NULL;
 }
 
 static void
@@ -441,7 +445,7 @@ add_cell (Sheet *sheet, const psiconv_sheet_cell psi_cell,
 {
 	GnmCell *cell;
 	GnmValue *val;
-	GnmExpr const *expr = NULL;
+	GnmExprTop const *expr = NULL;
 
 	cell = sheet_cell_fetch (sheet, psi_cell->column, psi_cell->row);
 	if (!cell)
@@ -457,14 +461,14 @@ add_cell (Sheet *sheet, const psiconv_sheet_cell psi_cell,
 		 * How does it store a user entered date ?
 		 */
 		if (val != NULL)
-			cell_set_expr_and_value (cell, expr, val, TRUE);
+			gnm_cell_set_expr_and_value (cell, expr, val, TRUE);
 		else
-			cell_set_expr (cell, expr);
+			gnm_cell_set_expr (cell, expr);
 	} else if (val != NULL) {
 		/* TODO : is there a notion of parse format ?
 		 * How does it store a user entered date ?
 		 */
-		cell_set_value (cell, val);
+		gnm_cell_set_value (cell, val);
 	} else {
 		/* TODO : send this warning to iocontext with details of
 		 * which sheet and cell.
@@ -472,7 +476,7 @@ add_cell (Sheet *sheet, const psiconv_sheet_cell psi_cell,
 		g_warning ("Cell with no value or expression ?");
 	}
 	if (expr)
-		gnm_expr_free (expr);
+		gnm_expr_top_unref (expr);
 
 	/* TODO: Perhaps this must be moved above set_format */
 	set_style(sheet,psi_cell->row,psi_cell->column,psi_cell->layout,
@@ -591,7 +595,7 @@ psiconv_stream_to_buffer (GsfInput *input, int maxlen)
 			}
 		}
 	}
-		
+
 	return buf;
 }
 
@@ -623,7 +627,7 @@ psiconv_read (IOContext *io_context, Workbook *wb, GsfInput *input)
 	else
 		gnumeric_io_error_info_set (io_context,
 		                            error_info_new_str(_("This Psion file is not a Sheet file.")));
-		
+
 
 out:
 	if (config)
@@ -658,4 +662,3 @@ out:
 		psiconv_buffer_free(buf);
 	return res;
 }
-
