@@ -8,7 +8,7 @@
  *    Andreas J. Guelzow (aguelzow@taliesin.ca)
  *
  * Port to Maemo:
- * 	Eduardo Lima  (eduardo.lima@indt.org.br)
+ *	Eduardo Lima  (eduardo.lima@indt.org.br)
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
@@ -47,7 +47,7 @@ typedef struct {
 	GList *openers;
 } file_format_changed_cb_data;
 
- 
+
 
 static gint
 file_opener_description_cmp (gconstpointer a, gconstpointer b)
@@ -83,7 +83,7 @@ make_format_chooser (GList *list, GtkComboBox *combo)
 						GO_FILE_OPENER (l->data));
 		else
 			descr = go_file_saver_get_description (
-				                GO_FILE_SAVER (l->data));
+						GO_FILE_SAVER (l->data));
 
 		gtk_combo_box_append_text (combo, descr);
 	}
@@ -123,7 +123,7 @@ gui_file_read (WBCGtk *wbcg, char const *uri,
 
 	go_cmd_context_set_sensitive (GO_CMD_CONTEXT (wbcg), FALSE);
 	io_context = gnumeric_io_context_new (GO_CMD_CONTEXT (wbcg));
-	wbv = wb_view_new_from_uri (uri, optional_format, io_context, 
+	wbv = wb_view_new_from_uri (uri, optional_format, io_context,
 				    optional_encoding);
 
 	if (gnumeric_io_error_occurred (io_context) ||
@@ -162,7 +162,7 @@ file_opener_find_by_id (GList *openers, char const *id)
 
 	if (id == NULL)
 		return 0;
-	
+
 	for (l = openers; l != NULL; l = l->next, i++) {
 		if (IS_GO_FILE_OPENER (l->data) &&
 		    strcmp (id, go_file_opener_get_id(l->data)) == 0)
@@ -173,15 +173,18 @@ file_opener_find_by_id (GList *openers, char const *id)
 }
 
 static void
-advanced_clicked (GtkButton *advanced, GtkFileChooser *fsel)
+cb_advanced_clicked (GtkButton *advanced, GtkFileChooser *fsel)
 {
 	GtkWidget *extra = g_object_get_data (G_OBJECT (advanced), "extra");
 
+	gtk_button_set_use_underline (advanced, TRUE);
 	if (gtk_file_chooser_get_extra_widget (fsel)) {
-		gtk_button_set_label (advanced, _("Advanced"));
+		 /* xgettext: If possible try to use the same mnemonic for
+		  * Advanced and Simple */
+		gtk_button_set_label (advanced, _("Advanc_ed"));
 		gtk_file_chooser_set_extra_widget (fsel, NULL);
 	} else {
-		gtk_button_set_label (advanced, _("Simple"));
+		gtk_button_set_label (advanced, _("Simpl_e"));
 		gtk_file_chooser_set_extra_widget (fsel, extra);
 	}
 }
@@ -212,8 +215,8 @@ gui_file_open (WBCGtk *wbcg, char const *default_format)
 	openers = g_list_prepend (openers, NULL);
 	opener_default = file_opener_find_by_id (openers, default_format);
 	title = (opener_default == 0)
-		? _("Load file") 
-		: (go_file_opener_get_description 
+		? _("Load file")
+		: (go_file_opener_get_description
 		   (g_list_nth_data (openers, opener_default)));
 	data.openers = openers;
 
@@ -241,7 +244,7 @@ gui_file_open (WBCGtk *wbcg, char const *default_format)
 			       "title", _("Select a file"),
 			       NULL));
 
-	advanced_button = gtk_button_new_from_stock (_("Advanced"));
+	advanced_button = gtk_button_new_with_mnemonic (_("Advanc_ed"));
 	gtk_widget_show (advanced_button);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fsel)->action_area),
 			    advanced_button, FALSE, TRUE, 6);
@@ -264,7 +267,7 @@ gui_file_open (WBCGtk *wbcg, char const *default_format)
 	gtk_file_chooser_unselect_all (fsel);
 
 	/* Filters */
-	{	
+	{
 		GtkFileFilter *filter;
 
 		filter = gtk_file_filter_new ();
@@ -298,6 +301,9 @@ gui_file_open (WBCGtk *wbcg, char const *default_format)
 				  0, 1, 1, 2, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 5, 2);
 		gtk_label_set_mnemonic_widget (GTK_LABEL (data.charmap_label),
 					       go_charmap_sel);
+
+		g_object_set_data_full (G_OBJECT (advanced_button), "extra",
+			g_object_ref (box), g_object_unref);
 #ifdef USE_HILDON
 		/*
 		 * Don't need to show the vbox. This is here just to avoid the warning :
@@ -307,13 +313,9 @@ gui_file_open (WBCGtk *wbcg, char const *default_format)
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fsel)->vbox), box, FALSE, TRUE, 6);
 #else
 		gtk_widget_show_all (box);
-		g_object_set_data_full (G_OBJECT (advanced_button),
-					"extra",
-					g_object_ref (box),
-					g_object_unref);
 		g_signal_connect (G_OBJECT (advanced_button),
 				  "clicked",
-				  G_CALLBACK (advanced_clicked),
+				  G_CALLBACK (cb_advanced_clicked),
 				  fsel);
 #endif
 	}
@@ -383,8 +385,8 @@ gui_file_save_as (WBCGtk *wbcg, WorkbookView *wb_view)
 	wbcg2 = wbcg_find_for_workbook (wb, wbcg, NULL, NULL);
 
 	for (l = go_get_file_savers (); l; l = l->next) {
-		if ((l->data == NULL) || 
-		    (go_file_saver_get_save_scope (GO_FILE_SAVER (l->data)) 
+		if ((l->data == NULL) ||
+		    (go_file_saver_get_save_scope (GO_FILE_SAVER (l->data))
 		     != FILE_SAVE_RANGE))
 			savers = g_list_prepend (savers, l->data);
 	}
@@ -408,7 +410,7 @@ gui_file_save_as (WBCGtk *wbcg, WorkbookView *wb_view)
 	gtk_dialog_set_default_response (GTK_DIALOG (fsel), GTK_RESPONSE_OK);
 
 	/* Filters */
-	{	
+	{
 		GtkFileFilter *filter;
 		GList *l;
 
@@ -495,7 +497,7 @@ gui_file_save_as (WBCGtk *wbcg, WorkbookView *wb_view)
 			goto out;
 		uri = gtk_file_chooser_get_uri (fsel);
 		if (!go_url_check_extension (uri,
-					     go_file_saver_get_extension (fs), 
+					     go_file_saver_get_extension (fs),
 					     &uri2) &&
 		    !go_gtk_query_yes_no (GTK_WINDOW (fsel),
 					  TRUE,
