@@ -15,9 +15,8 @@
 #include "item-grid.h"
 
 #include "gnm-pane-impl.h"
-#include "workbook-edit.h"
+#include "wbc-gtk-impl.h"
 #include "workbook-view.h"
-#include "workbook-control-gui-priv.h"
 #include "sheet-control-gui-priv.h"
 #include "sheet.h"
 #include "sheet-view.h"
@@ -364,8 +363,8 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	FooCanvas *canvas = item->canvas;
 	GnmPane *pane = GNM_PANE (canvas);
 	Sheet const *sheet = scg_sheet (pane->simple.scg);
-	WorkbookControlGUI *wbcg = scg_wbcg (pane->simple.scg);
-	GnmCell const * const edit_cell = wbcg->wb_control.editing_cell;
+	WBCGtk *wbcg = scg_wbcg (pane->simple.scg);
+	GnmCell const * const edit_cell = wbcg->editing_cell;
 	ItemGrid *ig = ITEM_GRID (item);
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 	int const dir = sheet->text_is_rtl ? -1 : 1;
@@ -412,7 +411,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expo
 	g_printerr ("%s:", cell_coord_name (start_col, start_row));
 	g_printerr ("%s <= %d vs %d", cell_coord_name(end_col, end_row), y, expose->area.y);
 	g_printerr (" [%s]\n", cell_coord_name (ig->bound.end.col, ig->bound.end.row));
-	
+
 #endif
 
 	/* clip to bounds */
@@ -794,7 +793,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	FooCanvas    *canvas = item->canvas;
 	GnmPane *pane = GNM_PANE (canvas);
 	SheetControlGUI *scg = ig->scg;
-	WorkbookControlGUI *wbcg = scg_wbcg (scg);
+	WBCGtk *wbcg = scg_wbcg (scg);
 	SheetControl	*sc = (SheetControl *)scg;
 	SheetView	*sv = sc_view (sc);
 	Sheet		*sheet = sv_sheet (sv);
@@ -823,7 +822,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	 * ends the edit.  */
 	if (scg->selected_objects == NULL)
 		wbcg_focus_cur_scg (wbcg);
-	else if (wbcg_edit_get_guru (wbcg) == NULL)
+	else if (wbc_gtk_get_guru (wbcg) == NULL)
 		scg_mode_edit (scg);
 
 	/* If we were already selecting a range of cells for a formula,
@@ -856,7 +855,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	}
 
 	/* While a guru is up ignore clicks */
-	if (wbcg_edit_get_guru (wbcg) != NULL)
+	if (wbc_gtk_get_guru (wbcg) != NULL)
 		return TRUE;
 
 	/* This was a regular click on a cell on the spreadsheet.  Select it.
@@ -886,7 +885,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	if (edit_showed_dialog)
 		return TRUE;  /* we already ignored the button release */
 
-      	switch (event->button) {
+	switch (event->button) {
 	case 1: {
 		guint32 double_click_time;
 
@@ -914,9 +913,9 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 		break;
 	}
 
-      	case 2: break;
+	case 2: break;
 
-      	case 3: scg_context_menu (scg, event, FALSE, FALSE);
+	case 3: scg_context_menu (scg, event, FALSE, FALSE);
 		break;
 	default :
 		break;
@@ -1012,8 +1011,8 @@ item_grid_event (FooCanvasItem *item, GdkEvent *event)
 		case ITEM_GRID_SELECTING_FORMULA_RANGE :
 /*  Removal of this code (2 lines)                                                */
 /*  should fix http://bugzilla.gnome.org/show_bug.cgi?id=63485                    */
-/* 			sheet_make_cell_visible (sheet,                           */
-/* 				sheet->edit_pos.col, sheet->edit_pos.row, FALSE); */
+/*			sheet_make_cell_visible (sheet,                           */
+/*				sheet->edit_pos.col, sheet->edit_pos.row, FALSE); */
 			/* Fall through */
 		case ITEM_GRID_SELECTING_CELL_RANGE :
 			wb_view_selection_desc (
