@@ -13,6 +13,7 @@
 #include "gnumeric.h"
 #include "print-info.h"
 
+#include "print.h"
 #include "gutils.h"
 #include "ranges.h"
 #include "gnm-format.h"
@@ -20,6 +21,7 @@
 #include "sheet.h"
 #include "value.h"
 #include "workbook.h"
+#include "workbook-view.h"
 #include "gnumeric-gconf.h"
 #include "gnumeric-gconf-priv.h"
 
@@ -33,6 +35,8 @@
 #include <locale.h>
 #include <time.h>
 
+#define PDF_SAVER_ID "Gnumeric_pdf:pdf_assistant"
+
 #define MAX_SAVED_CUSTOM_HF_FORMATS 9
 
 GList *hf_formats = NULL;
@@ -124,12 +128,17 @@ print_info_free (PrintInformation *pi)
 {
 	g_return_if_fail (pi != NULL);
 
+	if (NULL != pi->page_breaks.v)
+		gnm_page_breaks_free (pi->page_breaks.v);
+	if (NULL != pi->page_breaks.h)
+		gnm_page_breaks_free (pi->page_breaks.h);
+
 	print_hf_free (pi->header);
 	print_hf_free (pi->footer);
 
 	if (pi->page_setup)
 		g_object_unref (pi->page_setup);
-	
+
 	g_free (pi);
 }
 
@@ -176,14 +185,14 @@ load_formats (void)
 			hf_formats = g_list_prepend (hf_formats, format);
 			hf_formats_base_num++;
 		}
-	} 
+	}
 
 	/* Now append the custom formats */
 	{
 		GSList const *left;
 		GSList const *middle;
 		GSList const *right;
-		
+
 		left = gnm_app_prefs->printer_header_formats_left;
 		middle = gnm_app_prefs->printer_header_formats_middle;
 		right = gnm_app_prefs->printer_header_formats_right;
@@ -192,13 +201,13 @@ load_formats (void)
 		{
 			PrintHF *format;
 
-			format = print_hf_new 
+			format = print_hf_new
 				(left->data ? left->data : "",
 				 middle->data ? middle->data : "",
 				 right->data ? right->data : "");
 
 			hf_formats = g_list_prepend (hf_formats, format);
-			
+
 			left = left->next;
 			middle = middle->next;
 			right = right->next;
@@ -229,19 +238,19 @@ print_info_load_defaults (PrintInformation *res)
 
 	res->scaling.type = gnm_app_prefs->print_scale_percentage
 		? PRINT_SCALE_PERCENTAGE : PRINT_SCALE_FIT_PAGES;
-	res->scaling.percentage.x = res->scaling.percentage.y 
+	res->scaling.percentage.x = res->scaling.percentage.y
 		= gnm_app_prefs->print_scale_percentage_value;
 	res->scaling.dim.cols = gnm_app_prefs->print_scale_width;
 	res->scaling.dim.rows = gnm_app_prefs->print_scale_height;
-	res->margin.top = gnm_app_prefs->print_margin_top;
-	res->margin.bottom = gnm_app_prefs->print_margin_bottom;
+	res->edge_to_below_header = gnm_app_prefs->print_margin_top;
+	res->edge_to_above_footer = gnm_app_prefs->print_margin_bottom;
 	res->desired_display.top = gnm_app_prefs->desired_display;
 	res->desired_display.bottom = gnm_app_prefs->desired_display;
 	res->desired_display.left = gnm_app_prefs->desired_display;
 	res->desired_display.right = gnm_app_prefs->desired_display;
 	res->desired_display.footer = gnm_app_prefs->desired_display;
 	res->desired_display.header = gnm_app_prefs->desired_display;
-	
+
 	res->repeat_top.use   = load_range (gnm_app_prefs->print_repeat_top,
 					    &res->repeat_top.range);
 	res->repeat_left.use  = load_range (gnm_app_prefs->print_repeat_left,
@@ -252,7 +261,7 @@ print_info_load_defaults (PrintInformation *res)
 	res->print_grid_lines      = gnm_app_prefs->print_grid_lines;
 	res->print_titles          = gnm_app_prefs->print_titles;
 	res->print_black_and_white = gnm_app_prefs->print_black_and_white;
-	res->print_even_if_only_styles 
+	res->print_even_if_only_styles
 		= gnm_app_prefs->print_even_if_only_styles;
 
 	res->print_across_then_down = gnm_app_prefs->print_order_across_then_down;
@@ -292,6 +301,8 @@ print_info_new (gboolean load_defaults)
 	res->n_copies	   = 0;
 
 	res->page_setup = NULL;
+	res->page_breaks.v = NULL;
+	res->page_breaks.h = NULL;
 
 	if (load_defaults)
 		return print_info_load_defaults (res);
@@ -355,7 +366,9 @@ print_info_save (PrintInformation *pi)
 	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_WIDTH,  pi->scaling.dim.cols);
 	go_conf_set_int (node, PRINTSETUP_GCONF_SCALE_HEIGHT, pi->scaling.dim.rows);
 
-	gnm_gconf_set_print_tb_margins (&pi->margin, pi->desired_display.top);
+	gnm_gconf_set_print_tb_margins (pi->edge_to_below_header,
+					pi->edge_to_above_footer,
+					pi->desired_display.top);
 
 	gnm_gconf_set_print_center_horizontally (pi->center_horizontally);
 	gnm_gconf_set_print_center_vertically (pi->center_vertically);
@@ -364,7 +377,7 @@ print_info_save (PrintInformation *pi)
 	gnm_gconf_set_print_even_if_only_styles (pi->print_even_if_only_styles);
 	gnm_gconf_set_print_black_and_white (pi->print_black_and_white);
 	gnm_gconf_set_print_order_across_then_down (pi->print_across_then_down);
-	
+
 	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_TOP,
 		pi->repeat_top.use ? range_as_string (&pi->repeat_top.range) : "");
 	go_conf_set_string (node, PRINTSETUP_GCONF_REPEAT_LEFT,
@@ -401,7 +414,7 @@ unit_name_to_unit (char const *name)
 		return GTK_UNIT_INCH;
 	if (!g_ascii_strcasecmp (name, "inches"))
 		return GTK_UNIT_INCH;
-	
+
 	return GTK_UNIT_POINTS;
 }
 
@@ -484,7 +497,7 @@ render_file (GString *target, HFRenderInfo *info, char const *args)
 			go_doc_get_uri (GO_DOC (info->sheet->workbook)));
 		g_string_append (target, name);
 		g_free (name);
-	} else 
+	} else
 		g_string_append (target, _("File Name"));
 }
 
@@ -496,7 +509,7 @@ render_path (GString *target, HFRenderInfo *info, char const *args)
 			go_doc_get_uri (GO_DOC (info->sheet->workbook)), TRUE);
 		g_string_append (target, path);
 		g_free (path);
-	} else 
+	} else
 		g_string_append (target, _("Path "));
 }
 
@@ -538,7 +551,7 @@ render_opcode (GString *target, char /* non-const */ *opcode,
 		if (render_ops [i].name_trans == NULL) {
 			render_ops [i].name_trans = g_utf8_casefold (_(render_ops [i].name), -1);
 		}
-		
+
 		if ((g_ascii_strcasecmp (render_ops [i].name, opcode) == 0) ||
 		    (g_utf8_collate (render_ops [i].name_trans, opcode_trans) == 0)) {
 			(*render_ops [i].render)(target, info, args);
@@ -600,15 +613,34 @@ hf_render_info_destroy (HFRenderInfo *hfi)
 	g_free (hfi);
 }
 
+static void
+pdf_write_workbook (GOFileSaver const *fs, IOContext *context,
+		    gconstpointer wbv_, GsfOutput *output)
+{
+	WorkbookView const *wbv = wbv_;
+	gnm_print_sheet (NULL, wb_view_cur_sheet (wbv), FALSE,
+			 PRINT_ALL_SHEETS, output);
+}
+
 void
 print_init (void)
 {
+	/* Install a pdf saver.  */
+	GOFileSaver *saver = go_file_saver_new (
+		PDF_SAVER_ID, "pdf",
+		_("PDF export"),
+		FILE_FL_WRITE_ONLY, pdf_write_workbook);
+	go_file_saver_register (saver);
+	g_object_unref (saver);
+
 	load_formats ();
 }
 
 void
 print_shutdown (void)
 {
+	go_file_saver_unregister (go_file_saver_for_id (PDF_SAVER_ID));
+
 	save_formats ();
 	destroy_formats ();
 }
@@ -619,27 +651,32 @@ print_info_dup (PrintInformation *src)
 	PrintInformation *dst = print_info_new (TRUE);
 
 	print_info_load_defaults (src);
-	
+
 	/* clear the refs in the new obj */
 	print_hf_free (dst->header);
 	print_hf_free (dst->footer);
 	if (dst->page_setup)
 		g_object_unref (dst->page_setup);
-	
-	
+
 	*dst = *src; /* bit bash */
-	
+
+	dst->page_breaks.v = gnm_page_breaks_dup (src->page_breaks.v);
+	dst->page_breaks.h = gnm_page_breaks_dup (src->page_breaks.h);
+
 	/* setup the refs for new content */
 	dst->header	   = print_hf_copy (src->header);
 	dst->footer	   = print_hf_copy (src->footer);
 	dst->page_setup    = gtk_page_setup_copy (src->page_setup);
-	
+
 	return dst;
 }
 
 void
 print_info_get_margins (PrintInformation *pi,
-			double *top, double *bottom, double *left, double *right)
+			double *top, double *bottom,
+			double *left, double *right,
+			double *edge_to_below_header,
+			double *edge_to_above_footer)
 {
 	g_return_if_fail (pi != NULL);
 	print_info_load_defaults (pi);
@@ -653,6 +690,10 @@ print_info_get_margins (PrintInformation *pi,
 		*left = gtk_page_setup_get_left_margin (pi->page_setup, GTK_UNIT_POINTS);
 	if (NULL != right)
 		*right = gtk_page_setup_get_right_margin (pi->page_setup, GTK_UNIT_POINTS);
+	if (NULL != edge_to_below_header)
+		*edge_to_below_header = pi->edge_to_below_header;
+	if (NULL != edge_to_above_footer)
+		*edge_to_above_footer = pi->edge_to_above_footer;
 }
 
 void
@@ -695,6 +736,27 @@ print_info_set_margin_right (PrintInformation *pi, double right)
 	gtk_page_setup_set_right_margin (pi->page_setup, right, GTK_UNIT_POINTS);
 }
 
+void
+print_info_set_edge_to_above_footer (PrintInformation *pi, double e_f)
+{
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	pi->edge_to_above_footer = e_f;
+}
+
+void
+print_info_set_edge_to_below_header (PrintInformation *pi, double e_h)
+{
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	g_return_if_fail (pi->page_setup != NULL);
+
+	pi->edge_to_below_header = e_h;
+}
+
+
 void
 print_info_set_margins (PrintInformation *pi,
 			double header, double footer, double left, double right)
@@ -718,18 +780,16 @@ print_info_set_margins (PrintInformation *pi,
 }
 
 void
-print_info_set_paper (PrintInformation *pi, char const *paper)
+page_setup_set_paper        (GtkPageSetup *page_setup, char const *paper)
 {
 	GtkPaperSize* gtk_paper;
 
-	g_return_if_fail (pi != NULL);
-	print_info_load_defaults (pi);
-	g_return_if_fail (pi->page_setup != NULL);
+	g_return_if_fail (page_setup != NULL);
 
 /* We are now using the standard paper names given by PWG 5101.1-2002 */
 /* We are trying to map some old gnome-print paper names.                  */
 
-/*  
+/*
  "A4" -> GTK_PAPER_NAME_A4
  "USLetter" -> GTK_PAPER_NAME_LETTER
  "USLegal" -> GTK_PAPER_NAME_LEGAL
@@ -741,44 +801,44 @@ print_info_set_paper (PrintInformation *pi, char const *paper)
 
 	if (g_ascii_strncasecmp ("A4", paper, 2) == 0)
 		paper = GTK_PAPER_NAME_A4;
-	if (g_ascii_strncasecmp ("A3", paper, 2) == 0)
+	else if (g_ascii_strncasecmp ("A3", paper, 2) == 0)
 	        paper = GTK_PAPER_NAME_A3;
-	if (g_ascii_strncasecmp ("A5", paper, 2) == 0)
+	else if (g_ascii_strncasecmp ("A5", paper, 2) == 0)
 		paper = GTK_PAPER_NAME_A5;
-	if (g_ascii_strncasecmp ("B5", paper, 2) == 0)
+	else if (g_ascii_strncasecmp ("B5", paper, 2) == 0)
 		paper = GTK_PAPER_NAME_B5;
-	if (g_ascii_strncasecmp ("USLetter", paper, 8) == 0)
+	else if (g_ascii_strncasecmp ("USLetter", paper, 8) == 0)
 		paper = GTK_PAPER_NAME_LETTER;
-	if (g_ascii_strncasecmp ("USLegal", paper, 7) == 0)
+	else if (g_ascii_strncasecmp ("US-Letter", paper, 9) == 0)
+		paper = GTK_PAPER_NAME_LETTER;
+	else if (g_ascii_strncasecmp ("USLegal", paper, 7) == 0)
 		paper = GTK_PAPER_NAME_LEGAL;
-	if (g_ascii_strncasecmp ("Executive", paper, 9) == 0)
+	else if (g_ascii_strncasecmp ("Executive", paper, 9) == 0)
 		paper = GTK_PAPER_NAME_EXECUTIVE;
 
 	gtk_paper = gtk_paper_size_new (paper);
-	gtk_page_setup_set_paper_size (pi->page_setup, gtk_paper);
+	gtk_page_setup_set_paper_size (page_setup, gtk_paper);
 	gtk_paper_size_free (gtk_paper);
 }
 
 void
-print_info_set_paper_width_height (PrintInformation *pi,
-				   double paper_width, double paper_height,
-				   GtkUnit unit)
+print_info_set_paper (PrintInformation *pi, char const *paper)
 {
-	
+	g_return_if_fail (pi != NULL);
+	print_info_load_defaults (pi);
+	page_setup_set_paper (pi->page_setup, paper);
 }
 
-char  *
-print_info_get_paper (PrintInformation *pi)
+char *
+page_setup_get_paper (GtkPageSetup *page_setup)
 {
-	char const *name;
 	GtkPaperSize* paper;
-	
-	g_return_val_if_fail (pi != NULL, g_strdup (GTK_PAPER_NAME_A4));
-	print_info_load_defaults (pi);
-	g_return_val_if_fail (pi->page_setup != NULL, g_strdup (GTK_PAPER_NAME_A4));
+	char const *name;
+
+	g_return_val_if_fail (page_setup != NULL, g_strdup (GTK_PAPER_NAME_A4));
+
+	paper = gtk_page_setup_get_paper_size (page_setup);
 
-	paper = gtk_page_setup_get_paper_size (pi->page_setup);
-	
 	if (gtk_paper_size_is_custom (paper)) {
 		double width = gtk_paper_size_get_width (paper, GTK_UNIT_MM);
 		double height = gtk_paper_size_get_height (paper, GTK_UNIT_MM);
@@ -786,15 +846,32 @@ print_info_get_paper (PrintInformation *pi)
 					width, height, width, height);
 	}
 
-	name =  gtk_paper_size_get_name (gtk_page_setup_get_paper_size (pi->page_setup));
+	name =  gtk_paper_size_get_name (gtk_page_setup_get_paper_size (page_setup));
+
+/* Working around gtk bug 426416 */
+	if (strncmp (name, "custom", 6) == 0) {
+		double width = gtk_paper_size_get_width (paper, GTK_UNIT_MM);
+		double height = gtk_paper_size_get_height (paper, GTK_UNIT_MM);
+		return g_strdup_printf ("custom_Gnm-%.0fx%.0fmm_%.0fx%.0fmm",
+					width, height, width, height);
+	}
 	return g_strdup (name);
 }
 
+char  *
+print_info_get_paper (PrintInformation *pi)
+{
+	g_return_val_if_fail (pi != NULL, g_strdup (GTK_PAPER_NAME_A4));
+	print_info_load_defaults (pi);
+
+	return page_setup_get_paper (pi->page_setup);
+}
+
 char  const*
 print_info_get_paper_display_name (PrintInformation *pi)
 {
 	GtkPaperSize* paper;
-	
+
 	g_return_val_if_fail (pi != NULL, "ERROR: No printinformation specified");
 	print_info_load_defaults (pi);
 	g_return_val_if_fail (pi->page_setup != NULL, "ERROR: No pagesetup loaded");
@@ -808,7 +885,7 @@ print_info_get_paper_width (PrintInformation *pi, GtkUnit unit)
 {
 	g_return_val_if_fail (pi != NULL, 0.);
 	print_info_load_defaults (pi);
-	
+
 	return gtk_page_setup_get_paper_width (pi->page_setup, unit);
 }
 
@@ -817,7 +894,7 @@ print_info_get_paper_height (PrintInformation *pi, GtkUnit unit)
 {
 	g_return_val_if_fail (pi != NULL, 0);
 	print_info_load_defaults (pi);
-	
+
 	return gtk_page_setup_get_paper_height (pi->page_setup, unit);
 }
 
@@ -836,19 +913,25 @@ print_info_get_page_setup (PrintInformation *pi)
 void
 print_info_set_page_setup (PrintInformation *pi, GtkPageSetup *page_setup)
 {
+	double header, footer, left, right;
+
 	g_return_if_fail (pi != NULL);
 	print_info_load_defaults (pi);
 
-	if (pi->page_setup)
+	if (pi->page_setup) {
 		g_object_unref (pi->page_setup);
-	pi->page_setup = page_setup;
+		print_info_get_margins (pi, &header, &footer, &left, &right,
+					NULL, NULL);
+		pi->page_setup = page_setup;
+		print_info_set_margins (pi, header, footer, left, right);
+	} else pi->page_setup = page_setup;
 }
 
 GtkPageOrientation
 print_info_get_paper_orientation (PrintInformation *pi)
 {
 	GtkPageOrientation orientation;
-	
+
 	g_return_val_if_fail (pi != NULL, GTK_PAGE_ORIENTATION_PORTRAIT);
 	print_info_load_defaults (pi);
 	g_return_val_if_fail (pi->page_setup != NULL, GTK_PAGE_ORIENTATION_PORTRAIT);
@@ -866,3 +949,108 @@ print_info_set_paper_orientation (PrintInformation *pi,
 
 	gtk_page_setup_set_orientation (pi->page_setup, orientation);
 }
+
+/**
+ * print_info_set_breaks :
+ * @pi : #PrintInformation
+ * @breaks : #GnmPageBreaks
+ * @is_col : Do @breaks split between columns or rows ?
+ *
+ * NOTE : Takes ownership of @breaks.  DO NOT FREE after calling.
+ **/
+void
+print_info_set_breaks (PrintInformation *pi,
+		       GnmPageBreaks    *breaks)
+{
+	GnmPageBreaks **target;
+
+	g_return_if_fail (pi != NULL);
+
+	target = breaks->is_vert ? &pi->page_breaks.v : &pi->page_breaks.h;
+
+	if (*target == breaks) /* just in case something silly happens */
+		return;
+
+	if (NULL != *target)
+		gnm_page_breaks_free (*target);
+	*target = breaks;
+}
+
+/********************************************************************
+ * Simple data structure to store page breaks defined as a wrapper in case we
+ * need something more extensive later. */
+
+/**
+ * gnm_page_breaks_new :
+ * @len : optional estimate of number of breaks that will be in the collection
+ * @is_vert :
+ *
+ * Allocate a collection of page breaks and provide some sanity checking for
+ * @len.
+ **/
+GnmPageBreaks *
+gnm_page_breaks_new (int len, gboolean is_vert)
+{
+	GnmPageBreaks *res = g_new (GnmPageBreaks, 1);
+
+	if (len < 0 || len > colrow_max (is_vert))
+		len = 0;
+	res->is_vert = is_vert;
+	res->details = g_array_sized_new (FALSE, FALSE,
+		sizeof (GnmPageBreak), len);
+
+	return res;
+}
+
+GnmPageBreaks *
+gnm_page_breaks_dup (GnmPageBreaks const *src)
+{
+	if (src != NULL) {
+		GnmPageBreaks *dst = gnm_page_breaks_new (src->details->len, src->is_vert);
+		GArray       *d_details = dst->details;
+		GArray const *s_details = src->details;
+		unsigned i;
+
+		/* no need to validate through gnm_page_breaks_append_break, just dup */
+		for (i = 0; i < s_details->len ; i++)
+			g_array_append_val (d_details,
+				g_array_index (s_details, GnmPageBreak, i));
+
+		return dst;
+	} else
+		return NULL;
+}
+
+void
+gnm_page_breaks_free (GnmPageBreaks *breaks)
+{
+	g_array_free (breaks->details, TRUE);
+	g_free (breaks);
+}
+
+gboolean
+gnm_page_breaks_append_break (GnmPageBreaks *breaks,
+			      int pos,
+			      GnmPageBreakType type)
+{
+	GnmPageBreak const *prev;
+	GnmPageBreak info;
+
+	g_return_val_if_fail (breaks != NULL, FALSE);
+
+	/* Do some simple validation */
+	if (pos < 0)
+		return FALSE;
+	if (breaks->details->len > 0) {
+		prev = &g_array_index (breaks->details, GnmPageBreak,
+			breaks->details->len-1);
+		if (prev->pos >= pos)
+			return FALSE;
+	}
+
+	info.pos   = pos;
+	info.type  = type;
+	g_array_append_val (breaks->details, info);
+
+	return TRUE;
+}
