@@ -34,6 +34,7 @@
 #include <goffice/utils/go-glib-extras.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
+#include <math.h>
 
 #ifndef USE_TILE_POOLS
 #define USE_TILE_POOLS 1
@@ -197,6 +198,8 @@ rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
 #else
 #define TILE_SIZE_COL 32
 #endif
+#define PARTIAL_TILE_COL (SHEET_MAX_COLS != TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL * TILE_SIZE_COL)
+
 
 /* This is good until 16M rows.  */
 #if SHEET_MAX_ROWS <= 16 * 16 * 16 * 16
@@ -208,6 +211,7 @@ rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
 #else
 #define	TILE_SIZE_ROW 64
 #endif
+#define PARTIAL_TILE_ROW (SHEET_MAX_ROWS != TILE_SIZE_ROW * TILE_SIZE_ROW * TILE_SIZE_ROW * TILE_SIZE_ROW)
 
 typedef enum {
 	TILE_UNDEFINED	= -1,
@@ -1070,7 +1074,7 @@ sheet_style_set_range (Sheet *sheet, GnmRange const *range,
  * @style : #GnmStyle
  *
  * NOTE : This is a simple wrapper for now.  When we support col/row styles it
- * 	will make life easier.
+ *	will make life easier.
  *
  * Change the complete style for a full col.
  * This function absorbs a reference to the new @style.
@@ -1089,7 +1093,7 @@ sheet_style_set_col (Sheet *sheet, int col, GnmStyle *style)
  * @pstyle : #GnmStyle
  *
  * NOTE : This is a simple wrapper for now.  When we support col/row styles it
- * 	will make life easier.
+ *	will make life easier.
  *
  * Apply a partial style to a full col.
  * The routine absorbs a reference to the partial style.
@@ -1108,7 +1112,7 @@ sheet_style_apply_col (Sheet *sheet, int col, GnmStyle *pstyle)
  * @style : #GnmStyle
  *
  * NOTE : This is a simple wrapper for now.  When we support col/row styles it
- * 	will make life easier.
+ *	will make life easier.
  *
  * Change the complete style for a full row.
  * This function absorbs a reference to the new @style.
@@ -1127,7 +1131,7 @@ sheet_style_set_row (Sheet  *sheet, int row, GnmStyle *style)
  * @pstyle : #GnmStyle
  *
  * NOTE : This is a simple wrapper for now.  When we support col/row styles it
- * 	will make life easier.
+ *	will make life easier.
  *
  * Apply a partial style to a full col.
  * The routine absorbs a reference to the partial style.
@@ -1406,7 +1410,7 @@ style_row_init (GnmBorder const * * *prev_vert,
 	 */
 	n = end_col - start_col + 3; /* 1 before, 1 after, 1 fencepost */
 	sr->vertical	 = mem;
-	sr->vertical 	-= start_col-1;
+	sr->vertical	-= start_col-1;
 	sr->top		 = sr->vertical + n;
 	sr->bottom	 = sr->top + n;
 	next_sr->top	 = sr->bottom; /* yes they should share */
@@ -1741,7 +1745,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 		sr.top [col] = none;
 
 	/* merge the bottom of the previous row */
- 	if (r->start.row > 0) {
+	if (r->start.row > 0) {
 		GnmBorder const ** roller;
 		sr.row = r->start.row - 1;
 		sheet_style_get_row (sheet, &sr);
@@ -1777,7 +1781,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 	}
 
 	/* merge the top of the next row */
- 	if (r->end.row < (SHEET_MAX_ROWS-1)) {
+	if (r->end.row < (SHEET_MAX_ROWS-1)) {
 		sr.row = r->end.row + 1;
 		sheet_style_get_row (sheet, &sr);
 	}
@@ -1913,6 +1917,8 @@ cb_style_extent (GnmStyle *style,
 		int i = corner_col;
 		if (data->res->end.col < tmp)
 			data->res->end.col = tmp;
+		if (data->res->start.col > corner_col)
+			data->res->start.col = corner_col;
 
 		/* only check the row if the style is not the most common in
 		 * all of the columns in the tile */
@@ -1926,6 +1932,8 @@ cb_style_extent (GnmStyle *style,
 		tmp = corner_row+height-1;
 		if (data->res->end.row < tmp)
 			data->res->end.row = tmp;
+		if (data->res->start.row > corner_row)
+			data->res->start.row = corner_row;
 	}
 }
 
@@ -1936,8 +1944,8 @@ cb_style_extent (GnmStyle *style,
  * @r     :
  * most_common_in_cols : optionally NULL.
  *
- * A simple implementation that find the max lower and right styles that are
- * visible.  If @most_common_in_cols is specified it finds the most common
+ * A simple implementation that finds the smallest range containing all visible styles
+ * and containing res. x If @most_common_in_cols is specified it finds the most common
  * style for each column (0..SHEET_MAX_COLS-1) and ignores that style in
  * boundary calculations.
  */
@@ -2007,6 +2015,18 @@ cb_style_list_add_node (GnmStyle *style,
 	range.end.col = corner_col + width - 1;
 	range.end.row = corner_row + height - 1;
 
+#if PARTIAL_TILE_COL
+	if (corner_col >= SHEET_MAX_COLS)
+		return;
+	range.end.col = MIN (range.end.col, SHEET_MAX_COLS - 1);
+#endif
+
+#if PARTIAL_TILE_ROW
+	if (corner_row >= SHEET_MAX_ROWS)
+		return;
+	range.end.row = MIN (range.end.row, SHEET_MAX_ROWS - 1);
+#endif
+
 	if (apply_to) {
 		range.start.col -= apply_to->start.col;
 		if (range.start.col < 0)
@@ -2184,6 +2204,57 @@ sheet_style_collect_conditions (Sheet const *sheet, GnmRange const *r)
 
 	return res;
 }
+static void
+cb_style_list_add_hlink (GnmStyle *style,
+			 int corner_col, int corner_row,
+			 int width, int height,
+			 GnmRange const *apply_to, gpointer user)
+{
+	/* collect only the area with validation */
+	if (NULL != gnm_style_get_hlink (style))
+		cb_style_list_add_node (style,
+			corner_col, corner_row, width, height, apply_to, user);
+}
+
+static gboolean
+style_hlink_equal (GnmStyle const *a, GnmStyle const *b)
+{
+	return	gnm_style_get_hlink (a) == gnm_style_get_hlink (b);
+}
+
+/**
+ * sheet_style_collect_hlinks :
+ * @sheet :
+ * @range :
+ *
+ * Returns a list of areas with hyperlinks, Caller is responsible for freeing.
+ **/
+GnmStyleList *
+sheet_style_collect_hlinks (Sheet const *sheet, GnmRange const *r)
+{
+	GnmStyleList *res = NULL;
+	StyleListMerge mi;
+
+	mi.style_equal = style_hlink_equal;
+	mi.cache = g_hash_table_new ((GHashFunc)&gnm_cellpos_hash,
+				     (GCompareFunc)&gnm_cellpos_equal);
+
+	foreach_tile (sheet->style_data->styles,
+		      TILE_TOP_LEVEL, 0, 0, r,
+		      cb_style_list_add_hlink, &mi);
+#ifdef DEBUG_STYLE_LIST
+	g_printerr ("=========\n");
+#endif
+	g_hash_table_foreach_remove (mi.cache, cb_hash_merge_horiz, &mi);
+	g_hash_table_foreach_remove (mi.cache, cb_hash_to_list, &res);
+#ifdef DEBUG_STYLE_LIST
+	g_printerr ("=========\n");
+#endif
+	g_hash_table_destroy (mi.cache);
+
+	return res;
+}
+
 static void
 cb_style_list_add_validation (GnmStyle *style,
 			      int corner_col, int corner_row,
@@ -2268,7 +2339,7 @@ sheet_style_set_list (Sheet *sheet, GnmCellPos const *corner,
 
 		gnm_style_ref (sr->style);
 		sheet_style_set_range (sheet, &r, sr->style);
-		spanflags |= required_updates_for_style (sr->style);
+		spanflags |= gnm_style_required_spanflags (sr->style);
 	}
 	return spanflags;
 }
