@@ -11,6 +11,7 @@
 #include <glib/gi18n.h>
 #include "gnumeric.h"
 #include "libgnumeric.h"
+#include "gutils.h"
 #include "gnumeric-paths.h"
 #include <goffice/app/go-plugin.h>
 #include "command-context-stderr.h"
@@ -40,7 +41,7 @@ static gboolean ssindex_list_mime_types = FALSE;
 static gboolean ssindex_run_indexer = FALSE;
 static char *ssindex_import_encoding = NULL;
 
-static GOptionEntry const ssindex_options [] = { 
+static GOptionEntry const ssindex_options [] = {
 	{
 		"version", 'v',
 		0, G_OPTION_ARG_NONE, &ssindex_show_version,
@@ -48,24 +49,6 @@ static GOptionEntry const ssindex_options [] = {
 		NULL
 	},
 
-	/* ---------------------------------------- */
-
-	{
-		"lib-dir", 'L',
-		0, G_OPTION_ARG_FILENAME, &gnumeric_lib_dir,
-		N_("Set the root library directory"),
-		N_("DIR")
-	},
-
-	{
-		"data-dir", 'D',
-		0, G_OPTION_ARG_FILENAME, &gnumeric_data_dir,
-		N_("Adjust the root data directory"),
-		N_("DIR")
-	},
-
-	/* ---------------------------------------- */
-
 	{
 		"list-mime-types", 'm',
 		0, G_OPTION_ARG_NONE, &ssindex_list_mime_types,
@@ -89,15 +72,15 @@ static GOptionEntry const ssindex_options [] = {
 
 	/* ---------------------------------------- */
 
-	{ NULL } 
+	{ NULL }
 };
 
 
 typedef struct {
-	IOContext 	   *context;
+	IOContext	   *context;
 	WorkbookView const *wb_view;
 	Workbook const	   *wb;
-	Sheet 		   *sheet;
+	Sheet		   *sheet;
 	GsfXMLOut	   *output;
 } IndexerState;
 
@@ -207,21 +190,21 @@ ssindex (char const *file, IOContext *ioc)
 }
 
 int
-main (int argc, char **argv)
+main (int argc, char const **argv)
 {
 	ErrorInfo	*plugin_errs;
 	int		 res = 0;
 	GOCmdContext	*cc;
 	GOptionContext *ocontext;
-	GError *error = NULL;	
+	GError *error = NULL;
 
-	g_thread_init (NULL);
-
-	gnm_pre_parse_init (argv[0]);
+	/* No code before here, we need to init threads */
+	argv = gnm_pre_parse_init (argc, argv);
 
 	ocontext = g_option_context_new (_("INFILE..."));
 	g_option_context_add_main_entries (ocontext, ssindex_options, GETTEXT_PACKAGE);
-	g_option_context_parse (ocontext, &argc, &argv, &error);
+	g_option_context_add_group	  (ocontext, gnm_get_option_group ());
+	g_option_context_parse (ocontext, &argc, (gchar ***)&argv, &error);
 	g_option_context_free (ocontext);
 
 	if (error) {
@@ -242,7 +225,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-	gnm_common_init (FALSE);
+	gnm_init (FALSE);
 
 	cc = cmd_context_stderr_new ();
 	gnm_plugins_init (GO_CMD_CONTEXT (cc));
@@ -272,6 +255,7 @@ main (int argc, char **argv)
 
 	g_object_unref (cc);
 	gnm_shutdown ();
+	gnm_pre_parse_shutdown ();
 
 	return res;
 }
