@@ -36,8 +36,11 @@
 #include "value.h"
 #include "gnm-format.h"
 #include <gsf/gsf-output-iconv.h>
+#include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-impl-utils.h>
 #include <goffice/utils/go-locale.h>
+#include <goffice/utils/go-glib-extras.h>
+#include <goffice/app/file.h>
 
 #include <string.h>
 #include <locale.h>
@@ -78,10 +81,9 @@ enum {
 void
 gnm_stf_export_options_sheet_list_clear (GnmStfExport *stfe)
 {
-	g_return_if_fail (stfe != NULL);
+	g_return_if_fail (IS_GNM_STF_EXPORT (stfe));
 
-	g_slist_foreach (stfe->sheet_list, (GFunc)g_object_unref, NULL);
-	g_slist_free (stfe->sheet_list);
+	go_slist_free_custom (stfe->sheet_list, g_object_unref);
 	stfe->sheet_list = NULL;
 }
 
@@ -96,13 +98,22 @@ gnm_stf_export_options_sheet_list_clear (GnmStfExport *stfe)
 void
 gnm_stf_export_options_sheet_list_add (GnmStfExport *stfe, Sheet *sheet)
 {
-	g_return_if_fail (stfe != NULL);
+	g_return_if_fail (IS_GNM_STF_EXPORT (stfe));
 	g_return_if_fail (IS_SHEET (sheet));
 
 	g_object_ref (sheet);
 	stfe->sheet_list = g_slist_append (stfe->sheet_list, sheet);
 }
 
+
+GSList *
+gnm_stf_export_options_sheet_list_get (const GnmStfExport *stfe)
+{
+	g_return_val_if_fail (IS_GNM_STF_EXPORT (stfe), NULL);
+
+	return stfe->sheet_list;
+}
+
 /* ------------------------------------------------------------------------- */
 
 static char *
@@ -117,7 +128,7 @@ try_auto_date (GnmValue *value, const GOFormat *format,
 	GString *xlfmt;
 
 	is_date = gnm_format_is_date_for_value (format, value) > 0;
-	is_time = (go_format_get_family (format) == GO_FORMAT_TIME);
+	is_time = gnm_format_is_time_for_value (format, value) > 0;
 
 	if (!is_date && !is_time)
 		return NULL;
@@ -310,12 +321,10 @@ gnm_stf_export (GnmStfExport *stfe)
 
 	if (stfe->locale) {
 		go_setlocale (LC_ALL, old_locale);
-		g_free (old_locale);		
+		g_free (old_locale);
 	}
 
-	g_object_set (G_OBJECT (stfe),
-		      "sink", sink,
-		      NULL);
+	g_object_set (G_OBJECT (stfe), "sink", sink, NULL);
 	g_object_unref (sink);
 
 	return result;
@@ -524,3 +533,145 @@ GSF_CLASS (GnmStfExport, gnm_stf_export,
 	   gnm_stf_export_class_init, gnm_stf_export_init, GSF_OUTPUT_CSV_TYPE)
 
 /* ------------------------------------------------------------------------- */
+/* ------------------------------------------------------------------------- */
+
+
+#include "wbc-gtk.h"
+#include <goffice/app/io-context.h>
+#include <goffice/app/io-context-priv.h>
+#include "dialog-stf-export.h"
+#include "workbook-view.h"
+
+static GnmStfExport *
+gnm_stf_get_stfe (GObject *obj)
+{
+	GnmStfExport *stfe = g_object_get_data (obj, "stfe");
+	if (!stfe) {
+		stfe = g_object_new (GNM_STF_EXPORT_TYPE,
+				     "quoting-triggers", ", \t\n\"",
+				     "separator", " ",
+				     NULL);
+		g_object_set_data_full (obj, "stfe", stfe, g_object_unref);
+	}
+	return stfe;		
+}
+
+static void
+gnm_stf_file_saver_save (GOFileSaver const *fs, IOContext *context,
+			 gconstpointer wbv, GsfOutput *output)
+{
+	Workbook *wb = wb_view_get_workbook (wbv);
+	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (wb));
+	GsfOutput *dummy_sink;
+
+	// TODO: move this GUI dependent code out of this
+	// filesaver into gui-file.c. After this, remove includes (see above).
+	if (IS_WBC_GTK (context->impl)) {
+		gboolean cancelled =
+			stf_export_dialog (WBC_GTK (context->impl), stfe, wb);
+		if (cancelled) {
+			gnumeric_io_error_unknown (context);
+			return;
+		}
+	}
+
+	if (!stfe->sheet_list)
+		gnm_stf_export_options_sheet_list_add
+			(stfe, wb_view_cur_sheet (wbv));
+
+	g_object_set (G_OBJECT (stfe), "sink", output, NULL);
+	if (gnm_stf_export (stfe) == FALSE)
+		go_cmd_context_error_import (GO_CMD_CONTEXT (context),
+			_("Error while trying to export file as text"));
+
+	/* We're not allowed to set a NULL sink, so use a dummy.  */
+	dummy_sink = gsf_output_memory_new ();
+	g_object_set (G_OBJECT (stfe), "sink", dummy_sink, NULL);
+	g_object_unref (dummy_sink);
+}
+
+static gboolean
+cb_set_export_option (const char *key, const char *value,
+		      GError **err, gpointer user)
+{
+	Workbook *wb = user;
+	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (wb));
+	const char *errtxt;
+
+	if (strcmp (key, "sheet") == 0) {
+		Sheet *sheet = workbook_sheet_by_name (wb, value);
+		if (!sheet) {
+			errtxt = _("There is no such sheet");
+			goto error;
+		}
+
+		gnm_stf_export_options_sheet_list_add (stfe, sheet);
+
+		return FALSE;
+	}
+
+	if (strcmp (key, "eol") == 0) {
+		const char *eol;
+		if (g_ascii_strcasecmp ("unix", value) == 0)
+			eol = "\n";
+		else if (g_ascii_strcasecmp ("mac", value) == 0)
+			eol = "\r";
+		else if	(g_ascii_strcasecmp ("windows", value) == 0)
+			eol = "\r\n";
+		else {
+			errtxt = _("eol must be one of unix, mac, and windows");
+			goto error;
+		}
+
+		g_object_set (G_OBJECT (stfe), "eol", eol, NULL);
+		return FALSE;
+	}
+
+	if (strcmp (key, "charset") == 0 ||
+	    strcmp (key, "locale") == 0 ||
+	    strcmp (key, "quote") == 0 ||
+	    strcmp (key, "separator") == 0 ||
+	    strcmp (key, "format") == 0 ||
+	    strcmp (key, "transliterate-mode") == 0 ||
+	    strcmp (key, "quoting-mode") == 0 ||
+	    strcmp (key, "quoting-on-whitespace") == 0)
+		return go_object_set_property
+			(G_OBJECT (stfe),
+			 key, key, value,
+			 err,
+			 (_("Invalid value for option %s: \"%s\"")));
+
+	errtxt = _("Invalid option for stf exporter");
+error:
+	if (err)
+		*err = g_error_new (go_error_invalid (), 0, errtxt);
+
+	return TRUE;
+}
+
+static gboolean
+gnm_stf_fs_set_export_options (GOFileSaver *fs,
+			       GODoc *doc,
+			       const char *options,
+			       GError **err,
+			       gpointer user)
+{
+	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (doc));
+	gnm_stf_export_options_sheet_list_clear (stfe);
+	return go_parse_key_value (options, err, cb_set_export_option, doc);
+}
+
+GOFileSaver *
+gnm_stf_file_saver_new (gchar const *id)
+{
+	GOFileSaver *fs = go_file_saver_new (id,
+					     "txt",
+					     _("Text (configurable)"),
+					     FILE_FL_WRITE_ONLY,
+					     gnm_stf_file_saver_save);
+	go_file_saver_set_save_scope (fs, FILE_SAVE_WORKBOOK);
+	g_signal_connect (G_OBJECT (fs), "set-export-options",
+			  G_CALLBACK (gnm_stf_fs_set_export_options),
+			  NULL);
+	return GO_FILE_SAVER (fs);
+}
