@@ -82,9 +82,8 @@ static GNM_ACTION_DEF (cb_file_new)
 	GdkScreen *screen = gtk_window_get_screen (wbcg_toplevel (wbcg));
 	Workbook *wb = workbook_new_with_sheets
 		(gnm_app_prefs->initial_sheet_number);
-	WorkbookControl *new_wbc = workbook_control_gui_new (NULL, wb, screen);
-	WBCGtk *new_wbcg = WBC_GTK (new_wbc);
-	wbcg_copy_toolbar_visibility (new_wbcg, wbcg);	
+	WBCGtk *new_wbcg = wbc_gtk_new (NULL, wb, screen, NULL);
+	wbcg_copy_toolbar_visibility (new_wbcg, wbcg);
 }
 
 static GNM_ACTION_DEF (cb_file_open)	{ gui_file_open (wbcg, NULL); }
@@ -93,7 +92,7 @@ static GNM_ACTION_DEF (cb_file_save_as)	{ gui_file_save_as (wbcg, wb_control_vie
 static GNM_ACTION_DEF (cb_file_sendto)	{
 	wb_view_sendto (wb_control_view (WORKBOOK_CONTROL (wbcg)), GO_CMD_CONTEXT (wbcg)); }
 static GNM_ACTION_DEF (cb_file_page_setup)
-{ 
+{
 	dialog_printer_setup (wbcg, wbcg_cur_sheet (wbcg));
 }
 
@@ -123,7 +122,7 @@ static GNM_ACTION_DEF (cb_file_print_area_clear)
 {
 	GnmParsePos pp;
 	GnmRange r;
-	
+
 	range_init_full_sheet (&r);
 	parse_pos_init_sheet (&pp, wbcg_cur_sheet (wbcg));
 	cmd_define_name	(WORKBOOK_CONTROL (wbcg), "Print_Area", &pp,
@@ -137,7 +136,7 @@ static GNM_ACTION_DEF (cb_file_print_area_show)
 	Sheet *sheet = wbcg_cur_sheet (wbcg);
 	SheetView *sv = sheet_get_view (sheet, wb_control_view (WORKBOOK_CONTROL (wbcg)));
 	GnmRange r = sheet_get_nominal_printarea (sheet);
-	
+
 	wb_control_sheet_focus (WORKBOOK_CONTROL (wbcg), sheet);
 	sv_selection_reset (sv);
 	sv_selection_add_range (sv, &r);
@@ -439,19 +438,19 @@ static GNM_ACTION_DEF (cb_edit_fill_autofill)
 		} while (do_loop);
 
 		/* Make it autofill in only one direction */
- 		if ((total->end.col - src.end.col) >=
+		if ((total->end.col - src.end.col) >=
 		    (total->end.row - src.end.row))
- 			src.end.row = total->end.row;
- 		else
- 			src.end.col = total->end.col;
+			src.end.row = total->end.row;
+		else
+			src.end.col = total->end.col;
 
- 		cmd_autofill (wbc, sheet, FALSE,
+		cmd_autofill (wbc, sheet, FALSE,
 			      total->start.col, total->start.row,
 			      src.end.col - total->start.col + 1,
 			      src.end.row - total->start.row + 1,
 			      total->end.col, total->end.row,
 			      FALSE);
- 	}
+	}
 }
 
 static GNM_ACTION_DEF (cb_edit_fill_series)
@@ -1202,7 +1201,7 @@ toggle_font_attr (WBCGtk *wbcg, GtkToggleAction *act,
 	new_style = gnm_style_new ();
 	switch (t) {
 	default :
-	case MSTYLE_FONT_BOLD:	 	gnm_style_set_font_bold (new_style, val); break;
+	case MSTYLE_FONT_BOLD:		gnm_style_set_font_bold (new_style, val); break;
 	case MSTYLE_FONT_ITALIC:	gnm_style_set_font_italic (new_style, val); break;
 	case MSTYLE_FONT_UNDERLINE:	gnm_style_set_font_uline (new_style, val); break;
 	case MSTYLE_FONT_STRIKETHROUGH: gnm_style_set_font_strike (new_style, val); break;
@@ -1390,7 +1389,7 @@ static GNM_ACTION_DEF (cb_format_column_unhide)
 static GNM_ACTION_DEF (cb_format_row_auto_fit)
 {
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	workbook_cmd_resize_selected_colrow (wbc, 
+	workbook_cmd_resize_selected_colrow (wbc,
 		wb_control_cur_sheet (wbc), FALSE, -1);
 }
 static GNM_ACTION_DEF (cb_set_row_height)
@@ -1418,8 +1417,8 @@ static GtkActionEntry const permanent_actions[] = {
 		{ "MenuEditClear",	GTK_STOCK_CLEAR, N_("C_lear") },
 		{ "MenuEditDelete",	GTK_STOCK_DELETE, N_("_Delete") },
 		{ "MenuEditSheet",	NULL, N_("S_heet") },
-	        { "MenuEditSelect",	NULL, N_("_Select") },
-	        { "MenuEditFill",	NULL, N_("F_ill") },
+		{ "MenuEditSelect",	NULL, N_("_Select") },
+		{ "MenuEditFill",	NULL, N_("F_ill") },
 	{ "MenuView",		NULL, N_("_View") },
 		{ "MenuViewWindows",		NULL, N_("_Windows") },
 		{ "MenuViewToolbars",		NULL, N_("_Toolbars") },
@@ -1464,11 +1463,11 @@ static GtkActionEntry const permanent_actions[] = {
 	{ "EditPaste", GTK_STOCK_PASTE, NULL,
 		NULL, N_("Paste the clipboard"),
 		G_CALLBACK (cb_edit_paste) },
-	{ "UndoLast", GTK_STOCK_UNDO, N_("_Undo"), 
-		NULL, N_("Undo the last action"), 
+	{ "UndoLast", GTK_STOCK_UNDO, N_("_Undo"),
+		NULL, N_("Undo the last action"),
 		G_CALLBACK (cb_edit_undo_last) },
 	{ "RedoLast", GTK_STOCK_REDO, N_("_Redo"),
-		NULL, N_("Redo the undone action"), 
+		NULL, N_("Redo the undone action"),
 		G_CALLBACK (cb_edit_redo_last) },
 
 	{ "HelpDocs", GTK_STOCK_HELP, N_("_Contents"),
@@ -1568,8 +1567,8 @@ static GtkActionEntry const actions[] = {
 /* Edit -> Select */
 
 	/* Note : The accelerators involving space are just for display
-	 * 	purposes.  We actually handle this in
-	 * 		gnm-pane.c:gnm_pane_key_mode_sheet
+	 *	purposes.  We actually handle this in
+	 *		gnm-pane.c:gnm_pane_key_mode_sheet
 	 *	with the rest of the key movement and rangeselection.
 	 *	Otherwise input methods would steal them */
 	{ "EditSelectAll", NULL, N_("Select _All"),
@@ -2127,12 +2126,12 @@ static GtkToggleActionEntry const toggle_actions[] = {
 		N_("Vertically Center"), G_CALLBACK (cb_align_vcenter), FALSE },
 	{ "AlignBottom", NULL,
 		N_("Align _Bottom"), NULL,
-	        N_("Align Bottom"), G_CALLBACK (cb_align_bottom), FALSE },
+		N_("Align Bottom"), G_CALLBACK (cb_align_bottom), FALSE },
 
 	{ "ViewStatusbar", NULL,
-	        N_("View _Statusbar"), NULL,
-	        N_("Toggle visibility of statusbar"),
-	        G_CALLBACK (cb_view_statusbar), TRUE },
+		N_("View _Statusbar"), NULL,
+		N_("Toggle visibility of statusbar"),
+		G_CALLBACK (cb_view_statusbar), TRUE },
 
 	{ "ViewFullScreen", GTK_STOCK_ZOOM_FIT,
 		N_("F_ull Screen"), FULLSCREEN_ACCEL,
