@@ -13,9 +13,9 @@
 #include <gnumeric.h>
 #include "gnumeric-expr-entry.h"
 
-#include <workbook-edit.h>
-#include <workbook-control-gui-priv.h>
+#include <wbc-gtk-impl.h>
 #include <sheet-control-gui-priv.h>
+#include <gnm-pane.h>
 #include <sheet-merge.h>
 #include <parse-util.h>
 #include <gui-util.h>
@@ -36,10 +36,10 @@
 #include <string.h>
 
 typedef struct {
-	int text_start;
-	int text_end;
 	GnmRangeRef ref;
-	gboolean  is_valid;
+	int	    text_start;
+	int	    text_end;
+	gboolean    is_valid;
 } Rangesel;
 
 struct _GnmExprEntry {
@@ -50,7 +50,7 @@ struct _GnmExprEntry {
 	SheetControlGUI		*scg;	/* the source of the edit */
 	Sheet			*sheet;	/* from scg */
 	GnmParsePos		 pp;	/* from scg->sv */
-	WorkbookControlGUI	*wbcg;	/* from scg */
+	WBCGtk			*wbcg;	/* from scg */
 	Rangesel		 rangesel;
 
 	GnmExprEntryFlags	 flags;
@@ -62,6 +62,8 @@ struct _GnmExprEntry {
 	gboolean                 is_cell_renderer;  /* as cell_editable */
 	gboolean                 editing_canceled;  /* as cell_editable */
 	gboolean                 ignore_changes; /* internal mutex */
+
+	gboolean       feedback_disabled;
 };
 
 typedef struct _GnmExprEntryClass {
@@ -98,8 +100,7 @@ static void     gee_rangesel_reset (GnmExprEntry *gee);
 static void     gee_rangesel_update_text (GnmExprEntry *gee);
 static void     gee_detach_scg (GnmExprEntry *gee);
 static void     gee_remove_update_timer (GnmExprEntry *range);
-static void     gee_notify_cursor_position (GObject *object, GParamSpec *pspec,
-					    GnmExprEntry *gee);
+static void     cb_gee_notify_cursor_position (GnmExprEntry *gee);
 
 static GtkObjectClass *parent_class = NULL;
 
@@ -118,6 +119,18 @@ split_char_p (unsigned char const *c)
 	}
 }
 
+static inline void
+gee_force_abs_rel (GnmExprEntry *gee)
+{
+	Rangesel *rs = &gee->rangesel;
+	if ((gee->flags & GNM_EE_FORCE_ABS_REF))
+		rs->ref.a.col_relative = rs->ref.b.col_relative =
+			rs->ref.a.row_relative = rs->ref.b.row_relative = FALSE;
+	else if ((gee->flags & GNM_EE_FORCE_REL_REF))
+		rs->ref.a.col_relative = rs->ref.b.col_relative =
+			rs->ref.a.row_relative = rs->ref.b.row_relative = TRUE;
+}
+
 static void
 gee_rangesel_reset (GnmExprEntry *gee)
 {
@@ -126,10 +139,9 @@ gee_rangesel_reset (GnmExprEntry *gee)
 	rs->text_start = 0;
 	rs->text_end = 0;
 	memset (&rs->ref, 0, sizeof (GnmRange));
-
-	/* restore the default based on the flags */
-	rs->ref.a.col_relative = rs->ref.b.col_relative = (gee->flags & GNM_EE_ABS_COL) != 0;
-	rs->ref.a.row_relative = rs->ref.b.row_relative = (gee->flags & GNM_EE_ABS_ROW) != 0;
+	if (gee->flags & GNM_EE_FORCE_REL_REF)
+		rs->ref.a.col_relative = rs->ref.b.col_relative =
+			rs->ref.a.row_relative = rs->ref.b.row_relative = TRUE;
 
 	gee->rangesel.is_valid = FALSE;
 }
@@ -176,14 +188,14 @@ cb_icon_clicked (GtkButton *icon,
 			g_assert (GTK_IS_CONTAINER (old_entry_parent));
 
 			g_object_set_data_full (G_OBJECT (entry), "old_entry_parent",
-						gtk_widget_ref (old_entry_parent),
-						(GDestroyNotify) gtk_widget_unref);
+						g_object_ref (old_entry_parent),
+						(GDestroyNotify) g_object_unref);
 
 			g_return_if_fail ((GtkWidget *) entry != old_toplevel_child);
 
 			g_object_set_data_full (G_OBJECT (entry), "old_toplevel_child",
-						gtk_widget_ref (old_toplevel_child),
-						(GDestroyNotify) gtk_widget_unref);
+						g_object_ref (old_toplevel_child),
+						(GDestroyNotify) g_object_unref);
 
 			gtk_window_get_size (GTK_WINDOW (toplevel), &width, &height);
 			g_object_set_data (G_OBJECT (entry), "old_window_width", GUINT_TO_POINTER (width));
@@ -234,11 +246,11 @@ cb_icon_clicked (GtkButton *icon,
 			old_entry_parent = g_object_get_data (G_OBJECT (entry), "old_entry_parent");
 			g_assert (GTK_IS_CONTAINER (old_entry_parent));
 
-			gtk_widget_ref (GTK_WIDGET (entry));
+			g_object_ref (entry);
 			gtk_container_remove (GTK_CONTAINER (toplevel), GTK_WIDGET (entry));
 			gtk_container_add (GTK_CONTAINER (toplevel), old_toplevel_child);
 			gtk_container_add (GTK_CONTAINER (old_entry_parent), GTK_WIDGET (entry));
-			gtk_widget_unref (GTK_WIDGET (entry));
+			g_object_unref (entry);
 
 			container_props = g_object_get_data (G_OBJECT (entry), "container_props");
 			container_props_pspec = g_object_get_data (G_OBJECT (entry), "container_props_pspec");
@@ -297,12 +309,12 @@ gee_set_property (GObject      *object,
 		break;
 
 	case PROP_SCG:
-		gnm_expr_entry_set_scg (gee, 
+		gnm_expr_entry_set_scg (gee,
 			SHEET_CONTROL_GUI (g_value_get_object (value)));
 		break;
 	case PROP_WBCG:
 		g_return_if_fail (gee->wbcg == NULL);
-		gee->wbcg = WORKBOOK_CONTROL_GUI (g_value_get_object (value));
+		gee->wbcg = WBC_GTK (g_value_get_object (value));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -338,32 +350,78 @@ gee_get_property (GObject      *object,
 }
 
 static void
-cb_entry_activate (G_GNUC_UNUSED GtkWidget *w, GnmExprEntry *gee)
+cb_entry_activate (GnmExprEntry *gee)
 {
 	g_signal_emit (G_OBJECT (gee), signals [ACTIVATE], 0);
 	gnm_expr_entry_signal_update (gee, TRUE);
 }
 
 static void
-cb_entry_changed (G_GNUC_UNUSED GtkEntry *ignored,
-		  GnmExprEntry *gee)
+gee_destroy_feedback_range (GnmExprEntry *gee)
 {
-	if (!gee->ignore_changes) {
-		if (!gee->is_cell_renderer &&
-		    !gnm_expr_entry_can_rangesel (gee) &&
-		    gee->scg != NULL)
-			scg_rangesel_stop (gee->scg, FALSE);
+	SCG_FOREACH_PANE (gee->scg, pane,
+		gnm_pane_expr_cursor_stop (pane););
+}
+
+/* WARNING : DO NOT CALL THIS FROM FROM UPDATE.  It may create another
+ *           canvas-item which would in turn call update and confuse the
+ *           canvas.
+ */
+static void
+gee_scan_for_range (GnmExprEntry *gee)
+{
+	GnmRange  range;
+	Sheet *sheet = scg_sheet (gee->scg);
+	Sheet *parse_sheet;
+
+	parse_pos_init_editpos (&gee->pp, scg_view (gee->scg));
+	if (!gee->feedback_disabled) {
+		gnm_expr_entry_find_range (gee);
+		if (gnm_expr_entry_get_rangesel (gee, &range, &parse_sheet) &&
+		    parse_sheet == sheet) {
+			SCG_FOREACH_PANE (gee->scg, pane,
+				gnm_pane_expr_cursor_bound_set (pane, &range););
+			return;
+		}
 	}
 
+	gee_destroy_feedback_range (gee);
+}
+
+static void
+gee_update_env (GnmExprEntry *gee)
+{
+	if (!gee->ignore_changes) {
+		if (NULL != gee->scg &&
+#warning why do we want this dichotomy
+		    !gee->is_cell_renderer &&
+		    !gnm_expr_entry_can_rangesel (gee))
+			scg_rangesel_stop (gee->scg, FALSE);
+
+		if (gnm_expr_char_start_p (gtk_entry_get_text (gee->entry)))
+			gee_scan_for_range (gee);
+	}
+
+}
+static void
+cb_gee_notify_cursor_position (GnmExprEntry *gee)
+{
+	gee_update_env (gee);
+}
+
+static void
+cb_entry_changed (GnmExprEntry *gee)
+{
+	gee_update_env (gee);
 	g_signal_emit (G_OBJECT (gee), signals [CHANGED], 0);
 }
 
 static gboolean
-cb_gee_key_press_event (GtkEntry	  *entry,
-			GdkEventKey	  *event,
-			GnmExprEntry *gee)
+cb_gee_key_press_event (GtkEntry	*entry,
+			GdkEventKey	*event,
+			GnmExprEntry	*gee)
 {
-	WorkbookControlGUI *wbcg  = gee->wbcg;
+	WBCGtk *wbcg  = gee->wbcg;
 	int state = gnumeric_filter_modifiers (event->state);
 
 	switch (event->keyval) {
@@ -380,8 +438,6 @@ cb_gee_key_press_event (GtkEntry	  *entry,
 		 * displayed in entry.
 		 */
 		Rangesel *rs = &gee->rangesel;
-		gboolean abs_cols = (gee->flags & GNM_EE_ABS_COL);
-		gboolean abs_rows = (gee->flags & GNM_EE_ABS_ROW);
 		gboolean c, r;
 
 		/* FIXME: since the range can't have changed we should just be able to */
@@ -389,28 +445,21 @@ cb_gee_key_press_event (GtkEntry	  *entry,
 
 		/* Look for a range */
 		if (rs->text_start >= rs->text_end)
-			gnm_expr_expr_find_range (gee);
+			gnm_expr_entry_find_range (gee);
 
 		/* no range found */
 		if (!rs->is_valid || rs->text_start >= rs->text_end)
 			return TRUE;
 
+		if ((GNM_EE_FORCE_ABS_REF | GNM_EE_FORCE_REL_REF) & gee->flags)
+			return TRUE;
+
 		c = rs->ref.a.col_relative;
 		r = rs->ref.a.row_relative;
-		if (abs_rows) {
-			if (abs_cols)
-				return TRUE;
-			gnm_cellref_set_row_ar (&rs->ref.a, &gee->pp, !c);
-			gnm_cellref_set_col_ar (&rs->ref.b, &gee->pp, !c);
-		} else if (abs_cols) {
-			gnm_cellref_set_row_ar (&rs->ref.a, &gee->pp, !r);
-			gnm_cellref_set_row_ar (&rs->ref.b, &gee->pp, !r);
-		} else {
-			gnm_cellref_set_col_ar (&rs->ref.a, &gee->pp, !c);
-			gnm_cellref_set_col_ar (&rs->ref.b, &gee->pp, !c);
-			gnm_cellref_set_row_ar (&rs->ref.a, &gee->pp, c^r);
-			gnm_cellref_set_row_ar (&rs->ref.b, &gee->pp, c^r);
-		}
+		gnm_cellref_set_col_ar (&rs->ref.a, &gee->pp, !c);
+		gnm_cellref_set_col_ar (&rs->ref.b, &gee->pp, !c);
+		gnm_cellref_set_row_ar (&rs->ref.a, &gee->pp, c^r);
+		gnm_cellref_set_row_ar (&rs->ref.b, &gee->pp, c^r);
 
 		gee_rangesel_update_text (gee);
 
@@ -447,7 +496,7 @@ cb_gee_key_press_event (GtkEntry	  *entry,
 			break;
 
 		/* Be careful to use the editing sheet */
-		sv = sheet_get_view (wbcg->wb_control.editing_sheet,
+		sv = sheet_get_view (wbcg->editing_sheet,
 			wb_control_view (WORKBOOK_CONTROL (wbcg)));
 
 		if (state & GDK_CONTROL_MASK)
@@ -493,7 +542,7 @@ cb_gee_button_press_event (G_GNUC_UNUSED GtkEntry *entry,
 
 	if (gee->scg) {
 		scg_rangesel_stop (gee->scg, FALSE);
-		gnm_expr_expr_find_range (gee);
+		gnm_expr_entry_find_range (gee);
 		g_signal_emit (G_OBJECT (gee), signals [CHANGED], 0);
 	}
 
@@ -521,6 +570,7 @@ gee_init (GnmExprEntry *gee)
 	gee->freeze_count = 0;
 	gee->update_timeout_id = 0;
 	gee->update_policy = GTK_UPDATE_CONTINUOUS;
+	gee->feedback_disabled = FALSE;
 	gee_rangesel_reset (gee);
 
 	gee->entry = GTK_ENTRY (gtk_entry_new ());
@@ -534,21 +584,16 @@ gee_init (GnmExprEntry *gee)
 		      "gtk-entry-select-on-focus", FALSE,
 		      NULL);
 
-	g_signal_connect (G_OBJECT (gee->entry),
-		"activate",
+	g_signal_connect_swapped (G_OBJECT (gee->entry), "activate",
 		G_CALLBACK (cb_entry_activate), gee);
-	g_signal_connect (G_OBJECT (gee->entry),
-		"changed",
+	g_signal_connect_swapped (G_OBJECT (gee->entry), "changed",
 		G_CALLBACK (cb_entry_changed), gee);
-	g_signal_connect (G_OBJECT (gee->entry),
-		"key_press_event",
+	g_signal_connect (G_OBJECT (gee->entry), "key_press_event",
 		G_CALLBACK (cb_gee_key_press_event), gee);
-	g_signal_connect (G_OBJECT (gee->entry),
-		"button_press_event",
+	g_signal_connect (G_OBJECT (gee->entry), "button_press_event",
 		G_CALLBACK (cb_gee_button_press_event), gee);
-	g_signal_connect (G_OBJECT (gee->entry),
-		"notify::cursor-position",
-		G_CALLBACK (gee_notify_cursor_position), gee);
+	g_signal_connect_swapped (G_OBJECT (gee->entry), "notify::cursor-position",
+		G_CALLBACK (cb_gee_notify_cursor_position), gee);
 	gtk_box_pack_start (GTK_BOX (gee), GTK_WIDGET (gee->entry),
 		TRUE, TRUE, 0);
 	gtk_widget_show (GTK_WIDGET (gee->entry));
@@ -617,39 +662,31 @@ gee_class_init (GObjectClass *gobject_class)
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_class,
 		PROP_WBCG,
-		g_param_spec_object ("wbcg", "WorkbookControlGUI",
+		g_param_spec_object ("wbcg", "WBCGtk",
 			"The toplevel GUI container associated with the entry.",
-			WORKBOOK_CONTROL_GUI_TYPE,
+			WBC_GTK_TYPE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
-static void
-cb_entry_activated (G_GNUC_UNUSED gpointer data,
-		    GnmExprEntry *entry)
-{
-	gtk_cell_editable_editing_done (GTK_CELL_EDITABLE (entry));
-}
+/***************************************************************************/
 
 static void
-gee_start_editing (GtkCellEditable *cell_editable,
-		   G_GNUC_UNUSED GdkEvent *event)
+gee_editable_start_editing (GtkCellEditable *cell_editable,
+			    G_GNUC_UNUSED GdkEvent *event)
 {
 	GtkEntry *entry = gnm_expr_entry_get_entry (GNM_EXPR_ENTRY (cell_editable));
-
 	GNM_EXPR_ENTRY (cell_editable)->is_cell_renderer = TRUE;
-
-	g_signal_connect (G_OBJECT (entry),
-		"activate",
-		G_CALLBACK (cb_entry_activated), cell_editable);
-
+	g_signal_connect_swapped (G_OBJECT (entry), "activate",
+		G_CALLBACK (gtk_cell_editable_editing_done), cell_editable);
 	gtk_widget_grab_focus (GTK_WIDGET (entry));
 }
 
 static void
 gee_cell_editable_init (GtkCellEditableIface *iface)
 {
-	iface->start_editing = gee_start_editing;
+	iface->start_editing = gee_editable_start_editing;
 }
+/***************************************************************************/
 
 GSF_CLASS_FULL (GnmExprEntry, gnm_expr_entry,
 		NULL, NULL, gee_class_init, NULL,
@@ -754,14 +791,14 @@ gee_rangesel_update_text (GnmExprEntry *gee)
 }
 
 /**
- * gnm_expr_entry_rangesel_start
+ * gnm_expr_entry_find_range
  * @gee:   a #GnmExprEntry
  *
  * Look at the current selection to see how much of it needs to be changed when
  * selecting a range.
  **/
 void
-gnm_expr_expr_find_range (GnmExprEntry *gee)
+gnm_expr_entry_find_range (GnmExprEntry *gee)
 {
 	gboolean  single, formula_only;
 	char const *text, *cursor, *tmp, *ptr;
@@ -777,9 +814,8 @@ gnm_expr_expr_find_range (GnmExprEntry *gee)
 
 	text = gtk_entry_get_text (gee->entry);
 
-	rs->ref.a.col_relative = rs->ref.b.col_relative = (gee->flags & GNM_EE_ABS_COL) == 0;
-	rs->ref.a.row_relative = rs->ref.b.row_relative = (gee->flags & GNM_EE_ABS_ROW) == 0;
 	rs->ref.a.sheet = rs->ref.b.sheet = NULL;
+	gee_force_abs_rel (gee);
 	rs->is_valid = FALSE;
 	if (text == NULL)
 		return;
@@ -952,19 +988,6 @@ gnm_expr_entry_signal_update (GnmExprEntry *gee, gboolean user_requested)
 	gee_reset_update_timer (gee, user_requested);
 }
 
-static void
-gee_notify_cursor_position (G_GNUC_UNUSED GObject *object,
-			    G_GNUC_UNUSED GParamSpec *pspec,
-			    GnmExprEntry *gee)
-{
-	g_return_if_fail (IS_GNM_EXPR_ENTRY (gee));
-
-	if (gee->ignore_changes)
-		return;
-	if (!gnm_expr_entry_can_rangesel (gee))
-		scg_rangesel_stop (gee->scg, FALSE);
-}
-
 /**
  * gnm_expr_entry_set_update_policy:
  * @gee: a #GnmExprEntry
@@ -992,7 +1015,7 @@ gnm_expr_entry_set_update_policy (GnmExprEntry *gee,
 
 /**
  * gnm_expr_entry_new:
- * @wbcg : #WorkbookControlGUI non-NULL
+ * @wbcg : #WBCGtk non-NULL
  * @with_icon : append a rollup icon to the end of the entry
  *
  * Creates a new #GnmExprEntry, which is an entry widget with support
@@ -1003,7 +1026,7 @@ gnm_expr_entry_set_update_policy (GnmExprEntry *gee,
  * Return value: a new #GnmExprEntry.
  **/
 GnmExprEntry *
-gnm_expr_entry_new (WorkbookControlGUI *wbcg, gboolean with_icon)
+gnm_expr_entry_new (WBCGtk *wbcg, gboolean with_icon)
 {
 	return g_object_new (GNM_EXPR_ENTRY_TYPE,
 			     "scg",	  wbcg_cur_scg (wbcg),
@@ -1080,16 +1103,10 @@ gnm_expr_entry_set_flags (GnmExprEntry *gee,
 			  GnmExprEntryFlags flags,
 			  GnmExprEntryFlags mask)
 {
-	Rangesel *rs;
-
 	g_return_if_fail (IS_GNM_EXPR_ENTRY (gee));
 
 	gee->flags = (gee->flags & ~mask) | (flags & mask);
-	rs = &gee->rangesel;
-	if (mask & GNM_EE_ABS_COL)
-		rs->ref.a.col_relative = rs->ref.b.col_relative = (gee->flags & GNM_EE_ABS_COL) != 0;
-	if (mask & GNM_EE_ABS_ROW)
-		rs->ref.a.row_relative = rs->ref.b.row_relative = (gee->flags & GNM_EE_ABS_ROW) != 0;
+	gee_force_abs_rel (gee);
 }
 
 /**
@@ -1125,12 +1142,6 @@ gnm_expr_entry_set_scg (GnmExprEntry *gee, SheetControlGUI *scg)
 #endif
 }
 
-void
-gnm_expr_entry_set_parsepos (GnmExprEntry *gee, GnmParsePos const *pp)
-{
-	gee->pp = *pp;
-}
-
 /**
  * gnm_expr_entry_load_from_text :
  * @gee :
@@ -1305,24 +1316,6 @@ gnm_expr_entry_get_rangesel (GnmExprEntry const *gee,
 	return rs->is_valid;
 }
 
-/**
- * gnm_expr_entry_set_absolute
- * @gee:   a #GnmExprEntry
- *
- * Select absolute reference mode for rows and columns. Do not change
- * displayed text. This is a convenience function which wraps
- * gnm_expr_entry_set_flags.
- **/
-void
-gnm_expr_entry_set_absolute (GnmExprEntry *gee)
-{
-	GnmExprEntryFlags flags;
-
-	flags = GNM_EE_ABS_ROW | GNM_EE_ABS_COL;
-	gnm_expr_entry_set_flags (gee, flags, flags);
-}
-
-
 /**
  * gnm_expr_entry_can_rangesel
  * @gee:   a #GnmExprEntry
@@ -1352,17 +1345,18 @@ gnm_expr_entry_can_rangesel (GnmExprEntry *gee)
 
 	g_return_val_if_fail (IS_GNM_EXPR_ENTRY (gee), FALSE);
 
-	if (wbcg_edit_get_guru (gee->wbcg) != NULL && gee == gee->wbcg->edit_line.entry)
+	if (wbc_gtk_get_guru (gee->wbcg) != NULL &&
+	    gee == gee->wbcg->edit_line.entry)
 		return FALSE;
 
 	text = gtk_entry_get_text (gee->entry);
 
 	/* We need to be editing an expression */
-	if (wbcg_edit_get_guru (gee->wbcg) == NULL &&
+	if (wbc_gtk_get_guru (gee->wbcg) == NULL &&
 	    gnm_expr_char_start_p (text) == NULL)
 		return FALSE;
 
-	gnm_expr_expr_find_range (gee);
+	gnm_expr_entry_find_range (gee);
 	if (gee->rangesel.is_valid)
 		return TRUE;
 
@@ -1375,7 +1369,7 @@ gnm_expr_entry_can_rangesel (GnmExprEntry *gee)
  * @gee : the entry
  * @pp : a parse position
  * @start_sel : start range selection when things change.
- * @flags : 
+ * @flags :
  *
  * Attempts to parse the content of the entry line honouring
  * the flags.
@@ -1396,10 +1390,10 @@ gnm_expr_entry_parse (GnmExprEntry *gee, GnmParsePos const *pp,
 	if (text == NULL || text[0] == '\0')
 		return NULL;
 
-	if (gee->flags & GNM_EE_ABS_COL)
-		flags |= GNM_EXPR_PARSE_FORCE_ABSOLUTE_COL_REFERENCES;
-	if (gee->flags & GNM_EE_ABS_ROW)
-		flags |= GNM_EXPR_PARSE_FORCE_ABSOLUTE_ROW_REFERENCES;
+	if ((gee->flags & GNM_EE_FORCE_ABS_REF))
+		flags |= GNM_EXPR_PARSE_FORCE_ABSOLUTE_REFERENCES;
+	else if ((gee->flags & GNM_EE_FORCE_REL_REF))
+		flags |= GNM_EXPR_PARSE_FORCE_RELATIVE_REFERENCES;
 	if (!(gee->flags & GNM_EE_SHEET_OPTIONAL))
 		flags |= GNM_EXPR_PARSE_FORCE_EXPLICIT_SHEET_REFERENCES;
 
@@ -1440,11 +1434,13 @@ gnm_expr_entry_parse (GnmExprEntry *gee, GnmParsePos const *pp,
 
 /**
  * gnm_expr_entry_get_text
- * @ee :
+ * @gee :
  *
  * A small convenience routine.  Think long and hard before using this.
  * There are lots of parse routines that serve the common case.
- */
+ *
+ * Returns: The content of the entry.  Caller should not modify the result.
+ **/
 char const *
 gnm_expr_entry_get_text	(GnmExprEntry const *gee)
 {
@@ -1577,3 +1573,21 @@ gnm_expr_entry_editing_canceled (GnmExprEntry *gee)
 
 	return gee->editing_canceled;
 }
+
+/*****************************************************************************/
+
+void
+gnm_expr_entry_disable_highlight (GnmExprEntry *gee)
+{
+	g_return_if_fail (gee != NULL);
+	gee_destroy_feedback_range (gee);
+	gee->feedback_disabled = TRUE;
+}
+
+void
+gnm_expr_entry_enable_highlight (GnmExprEntry *gee)
+{
+	g_return_if_fail (gee != NULL);
+	gee->feedback_disabled = FALSE;
+}
+
